@@ -406,6 +406,13 @@ class Bot:
         # Add the queue_name - this makes it easier to find bots looking at
         # specific queues.
         bot_session.config.update({"queue_name": self.queue_name})
+        # Log all the user and bot session config values for debugging
+        for session, title in zip((user_session, bot_session), ("user", "bot")):
+            session.log.debug(f"-vvv- Config values for {title} session -vvv-")
+            for k, v in session.config.items():
+                if k != "TOKEN":
+                    session.log.debug(f"{k}: {v}")
+            session.log.debug(f"-^^^- Config values for {title} session -^^^-")
         self.bot_entity = user_session.bot.add(
             name=self.name, config=bot_session.config, meta=meta
         )
