@@ -121,3 +121,23 @@ class QalxInvalidTagError(QalxError):
 
 class QalxStepFunctionNotDefined(QalxError):
     """A specific Bot step function has not been defined by the user"""
+
+
+class QalxFactoryError(QalxError):
+    """Generic error with a Qalx factory"""
+
+
+class QalxFactoryValidationError(QalxFactoryError):
+    """Error when validating a factory"""
+
+
+class QalxFactoryPackError(QalxFactoryError):
+    """Error when packing a factory"""
+
+
+class QalxFactoryBuildError(QalxFactoryError):
+    """Error when building a factory"""
+
+
+class QalxFactoryDemolishError(QalxFactoryError):
+    """Error when demolishing a factory"""
