@@ -23,6 +23,21 @@ class QalxRotatingFileHandler(RotatingFileHandler):
         kwargs["mode"] = kwargs.get("mode", "w")
         super(QalxRotatingFileHandler, self).__init__(*args, **kwargs)
 
+    def rotate(self, *args, **kwargs):
+        """
+        Overridden in order to ignore permission errors.
+        This could happen when multiple processes are accessing the same
+        log file.  If this happens, rotation is suppressed until the lock
+        is dropped.  The log files will exceed the "maxBytes" value but logging
+        will continue normally.
+        """
+        try:
+            super(QalxRotatingFileHandler, self).rotate(*args, **kwargs)
+        except PermissionError:
+            # PermissionError: Multiple processes writing to same file.  Only
+            #                  likely on Windows
+            pass
+
 
 class QalxLogFormatter(logging.Formatter):
     """
