@@ -533,8 +533,9 @@ class FactoryBuildMixin:
                 *arguments,
                 bot_path,
             ],
-            # Redirect pipe to stderr so we can capture
+            # Redirect stderr and stdout to PIPE so we can capture
             # errors to give to the user in the main thread
+            stdout=PIPE,
             stderr=PIPE,
             env=modified_env,
         )
@@ -546,11 +547,17 @@ class FactoryBuildMixin:
         sleep(10)
         # .poll() will populate the returncode for us - but nothing else
         output.poll()
-        stderr = None
-        if output.returncode:
+        error = None
+        if output.returncode is not None:
             # Some sort of error occurred when starting this bot
-            _, stderr = output.communicate()
-        return output, stderr
+            stdout, stderr = output.communicate()
+            # There might be an error on `stdout` if there was an exception
+            # raised i.e. in the config if the log file path
+            # couldn't be created.  Therefore, join stdout and stderr together
+            # (giving more prominence to stderr) just in case there are issues
+            # in two places.
+            error = "\n".join([stderr.decode("utf-8"), stdout.decode("utf-8")])
+        return output, error
 
     def _create_stacks(self):
         """
