@@ -486,7 +486,9 @@ class AWSStack:
             if alarm_name is not None:
                 # There is an alarm on this sector, build the base alarm
                 # template
-                logical_id = self._logical_id(alarm_name, "alarm")
+                logical_id = self._logical_id(
+                    f"{sector_name}-{alarm_name}", "alarm"
+                )
                 alarms[logical_id] = self._build_alarm(alarm_name, region)
                 depends_on[logical_id].append(ec2_instance_logical_id)
                 dimensions[logical_id].append(
